- TestReport

# Test Report:

## Summary

START AT | 2019-03-06 19:08:51
DURATION | 0.131 seconds
PLATFORM | zybats 2.0.2.0 | CPython 3.7.0 | Windows-10-10.0.17134-SP0
STAT | TESTCASES (success/fail) | TESTSTEPS (success/fail/error/skip)
--- | --- | ---
total (details) => | 1 (0/1) | 3 (0/0/3/0)

## Details

### Shows how to use zybats ext api.

TOTAL: 3 | SUCCESS: 0 | FAILED: 0 | ERROR: 3 | SKIPPED: 0
Status | Name | Response Time | Detail
--- | --- | --- | ---
error | get token (setup) | N/A ms | log-1 ## Request and Response data × ### Name: ### Request:
url | N/A
method | N/A
headers |
### Response:
status_code | N/A
headers |
encoding | None
content_type |
### Validators:
check | comparator | expect value | actual value
--- | --- | --- | ---
### Statistics:
content_size(bytes) | N/A
response_time(ms) | N/A
elapsed(ms) | N/A
traceback ## Traceback Message ×
    Traceback (most recent call last):
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\parser.py", line 369, in get_mapping_variable
        return variables_mapping[variable_name]
    KeyError: 'URL'

    During handling of the above exception, another exception occurred:

    Traceback (most recent call last):
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\core\api.py", line 55, in test
        test_runner.run_test(test_dict)
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\runner.py", line 359, in run_test
        self._run_test(test_dict)
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\runner.py", line 200, in _run_test
        self.session_context.init_test_variables(test_variables)
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\context.py", line 47, in init_test_variables
        variable_value = self.eval_content(variable_value)
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\context.py", line 70, in eval_content
        self.FUNCTIONS_MAPPING
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\parser.py", line 607, in parse_data
        functions_mapping
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\parser.py", line 485, in parse_string_variables
        variable_value = get_mapping_variable(variable_name, variables_mapping)
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\parser.py", line 371, in get_mapping_variable
        raise exceptions.VariableNotFound("{} is not found.".format(variable_name))
    zybats.exceptions.VariableNotFound: URL is not found.
error | use redis ext api example | N/A ms | log-1 ## Request and Response data × ### Name: ### Request:
url | N/A
method | N/A
headers |
### Response:
status_code | N/A
headers |
encoding | None
content_type |
### Validators:
check | comparator | expect value | actual value
--- | --- | --- | ---
### Statistics:
content_size(bytes) | N/A
response_time(ms) | N/A
elapsed(ms) | N/A
traceback ## Traceback Message ×
    Traceback (most recent call last):
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\parser.py", line 369, in get_mapping_variable
        return variables_mapping[variable_name]
    KeyError: 'URL'

    During handling of the above exception, another exception occurred:

    Traceback (most recent call last):
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\core\api.py", line 55, in test
        test_runner.run_test(test_dict)
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\runner.py", line 359, in run_test
        self._run_test(test_dict)
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\runner.py", line 200, in _run_test
        self.session_context.init_test_variables(test_variables)
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\context.py", line 47, in init_test_variables
        variable_value = self.eval_content(variable_value)
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\context.py", line 70, in eval_content
        self.FUNCTIONS_MAPPING
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\parser.py", line 607, in parse_data
        functions_mapping
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\parser.py", line 485, in parse_string_variables
        variable_value = get_mapping_variable(variable_name, variables_mapping)
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\parser.py", line 371, in get_mapping_variable
        raise exceptions.VariableNotFound("{} is not found.".format(variable_name))
    zybats.exceptions.VariableNotFound: URL is not found.
error | use mysql ext api example | N/A ms | log-1 ## Request and Response data × ### Name: ### Request:
url | N/A
method | N/A
headers |
### Response:
status_code | N/A
headers |
encoding | None
content_type |
### Validators:
check | comparator | expect value | actual value
--- | --- | --- | ---
### Statistics:
content_size(bytes) | N/A
response_time(ms) | N/A
elapsed(ms) | N/A
traceback ## Traceback Message ×
    Traceback (most recent call last):
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\parser.py", line 369, in get_mapping_variable
        return variables_mapping[variable_name]
    KeyError: 'URL'

    During handling of the above exception, another exception occurred:

    Traceback (most recent call last):
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\core\api.py", line 55, in test
        test_runner.run_test(test_dict)
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\runner.py", line 359, in run_test
        self._run_test(test_dict)
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\runner.py", line 200, in _run_test
        self.session_context.init_test_variables(test_variables)
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\context.py", line 47, in init_test_variables
        variable_value = self.eval_content(variable_value)
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\context.py", line 70, in eval_content
        self.FUNCTIONS_MAPPING
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\parser.py", line 607, in parse_data
        functions_mapping
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\parser.py", line 485, in parse_string_variables
        variable_value = get_mapping_variable(variable_name, variables_mapping)
      File "c:\users\zuoyebang\appdata\local\programs\python\python37\lib\site-packages\zybats\parser.py", line 371, in get_mapping_variable
        raise exceptions.VariableNotFound("{} is not found.".format(variable_name))
    zybats.exceptions.VariableNotFound: URL is not found.